""" A utility for testing config options for the zebra test. Change settings until 
    the program identifies exactly 1 blob over the fish"""

"""IMPORTS"""
import numpy as np
import cv2
from skimage import feature
import time
import matplotlib.animation as am
from matplotlib import pyplot
import csv
import configparser

"""classes"""
class Config:
    """The magic numbers for the particle tracking, and other data """
    file_name:str
    output_name:str
    output_traj:str
    min_sigma:float
    max_sigma:float
    threshold:float
    overlap:float
    max_move:int
    backgroundFrame:int
    startFrame:int

    def __init__(self,path):
        config = configparser.ConfigParser()
        config.read(path)
        self.file_name = config['IO']['Input']
        self.output_name = config['IO']['OutputVid']
        self.output_traj = config['IO']['OutputTrajectory']
        self.min_sigma = float(config['Detector']['MinSigma'])
        self.max_sigma = float(config['Detector']['MaxSigma'])
        self. threshold = float(config['Detector']['Threshold'])
        self.overlap = float(config['Detector']['Overlap'])
        self.max_move = int(config['Detector']['MaxMove'])
        self.backgroundFrame = int(config['Background']['BackgroundFrame'])
        self.startFrame = int(config['Background']['StartFrame'])

def main():
    config = Config('config.ini')

    cap = cv2.VideoCapture(config.file_name)

    cap.set(1,config.backgroundFrame)
    ret,frame = cap.read()
    background = cv2.cvtColor(frame,cv2.COLOR_BGR2GRAY)

    cap.set(1,config.startFrame)
    ret,frame = cap.read()
    startFrame = cv2.cvtColor(frame,cv2.COLOR_BGR2GRAY)
    startFrame = cv2.subtract(background,startFrame)

    my_dog = feature.blob_dog(startFrame,min_sigma=config.min_sigma,
                                    max_sigma=config.max_sigma,
                                    overlap=config.overlap,
                                    threshold=config.threshold)

    fig,ax = pyplot.subplots()
    image = pyplot.imshow(startFrame,cmap='gray')

    pyplot.plot([x[1] for x in my_dog],
                [x[0] for x in my_dog],'o') 
    print(my_dog)

    pyplot.show()

if __name__ == "__main__":
    main()